"use strict";
var api_1 = require('./api/api');
var http_1 = require('@angular/http');
var authorised_request_1 = require('./api/authorised-request');
var index_1 = require('./index');
var local_storage_api_token_store_1 = require('./token-stores/local-storage-api-token-store');
var auth_tokens_validator_1 = require('./token-management/auth-tokens-validator');
var refresh_auth_token_service_1 = require('./token-management/refresh-auth-token-service');
var defaultOptions = {
    useTokenStore: defaultTokenStore,
    baseUrl: 'https://preprod-cdiscount.snowite.fr',
    onAuthError: function () { } //tslint:disable-line
};
function provideApollo(apolloOptions) {
    apolloOptions = apolloOptions || { baseUrl: defaultOptions.baseUrl };
    if (apolloOptions.useTokenStore && apolloOptions.onAuthError) {
        throw new Error('cannot specify both useTokenStore and onAuthError');
    }
    var opts = Object.assign({}, defaultOptions, apolloOptions);
    return [
        opts.useTokenStore(opts.onAuthError),
        {
            provide: api_1.ApiService,
            useFactory: function (http, tokenStore) {
                var authorisation = new authorised_request_1.SecureRequest(tokenStore, new auth_tokens_validator_1.JwtAuthTokensValidator(http, opts.baseUrl));
                return new api_1.ApiService(http, apolloOptions.baseUrl, authorisation);
            },
            deps: [http_1.Http, local_storage_api_token_store_1.LocalStorageApiTokenStore]
        },
        index_1.AccountService,
        index_1.CustomRadioService,
        index_1.ListService,
        {
            provide: refresh_auth_token_service_1.RefreshAuthTokenService,
            deps: [http_1.Http],
            useFactory: function (http) {
                return new refresh_auth_token_service_1.RefreshAuthTokenService(http, apolloOptions.baseUrl);
            }
        }
    ];
}
Object.defineProperty(exports, "__esModule", { value: true });
exports.default = provideApollo;
function defaultTokenStore(onAuthError) {
    return {
        provide: local_storage_api_token_store_1.LocalStorageApiTokenStore,
        useFactory: function () {
            var tokenStore = new local_storage_api_token_store_1.LocalStorageApiTokenStore();
            tokenStore.events.subscribe(function (event) {
                if (event.hasBeenRefreshed) {
                    tokenStore.save(event.auth_token, event.refresh_token);
                }
            }, function (error) {
                tokenStore.clear();
                onAuthError();
            });
            return tokenStore;
        }
    };
}
//# sourceMappingURL=provide-apollo.js.map